@@ -35,60 +35,14 @@ def print_papermill_version(ctx, param, value):
     ctx.exit()
 
 
-class OptionEatAll(click.Option):
-    # https://stackoverflow.com/a/48394004
-    def __init__(self, *args, **kwargs):
-        self.save_other_options = kwargs.pop('save_other_options', True)
-        nargs = kwargs.pop('nargs', -1)
-        assert nargs == -1, 'nargs, if set, must be -1 not {}'.format(nargs)
-        super(OptionEatAll, self).__init__(*args, **kwargs)
-        self._previous_parser_process = None
-        self._eat_all_parser = None
-
-    def add_to_parser(self, parser, ctx):
-
-        def parser_process(value, state):
-            # method to hook to the parser.process
-            done = False
-            value = [value]
-            if self.save_other_options:
-                # grab everything up to the next option
-                while state.rargs and not done:
-                    for prefix in self._eat_all_parser.prefixes:
-                        if state.rargs[0].startswith(prefix):
-                            done = True
-                    if not done:
-                        value.append(state.rargs.pop(0))
-            else:
-                # grab everything remaining
-                value += state.rargs
-                state.rargs[:] = []
-            value = tuple(value)
-
-            # call the actual process
-            self._previous_parser_process(value, state)
-
-        retval = super(OptionEatAll, self).add_to_parser(parser, ctx)
-        for name in self.opts:
-            our_parser = parser._long_opt.get(name) or parser._short_opt.get(name)
-            if our_parser:
-                self._eat_all_parser = our_parser
-                self._previous_parser_process = our_parser.process
-                our_parser.process = parser_process
-                break
-        return retval
-
-
 @click.command(context_settings=dict(help_option_names=['-h', '--help']))
 @click.argument('notebook_path', required=not INPUT_PIPED)
 @click.argument('output_path', required=not (INPUT_PIPED or OUTPUT_PIPED))
 @click.option(
-    '--parameters', '-p', multiple=True, help='Parameters to pass to the parameters cell.',
-    cls=OptionEatAll,
+    '--parameters', '-p', nargs=2, multiple=True, help='Parameters to pass to the parameters cell.'
 )
 @click.option(
-    '--parameters_raw', '-r', multiple=True, help='Parameters to be read as raw string.',
-    cls=OptionEatAll,
+    '--parameters_raw', '-r', nargs=2, multiple=True, help='Parameters to be read as raw string.'
 )
 @click.option(
     '--parameters_file', '-f', multiple=True, help='Path to YAML file containing parameters.'
@@ -121,7 +75,7 @@ class OptionEatAll(click.Option):
     ),
 )
 @click.option('--engine', help='The execution engine name to use in evaluating the notebook.')
-@click.option('--request-save-on-cell-execute', default=True,
+@click.option('--request-save-on-cell-execute/--no-request-save-on-cell-execute', default=True,
               help='Request save notebook after each cell execution')
 @click.option(
     '--prepare-only/--prepare-execute',
@@ -136,7 +90,17 @@ class OptionEatAll(click.Option):
 @click.option(
     '--log-output/--no-log-output',
     default=False,
-    help="Flag for writing notebook output to stderr.",
+    help="Flag for writing notebook output to the configured logger.",
+)
+@click.option(
+    '--stdout-file',
+    type=click.File(mode='w', encoding='utf-8'),
+    help="File to write notebook stdout output to.",
+)
+@click.option(
+    '--stderr-file',
+    type=click.File(mode='w', encoding='utf-8'),
+    help="File to write notebook stderr output to.",
 )
 @click.option(
     '--log-level',
@@ -147,7 +111,7 @@ class OptionEatAll(click.Option):
 @click.option(
     '--start_timeout', type=int, default=60, help="Time in seconds to wait for kernel to start."
 )
-@click.option('--report-mode/--not-report-mode', default=False, help="Flag for hiding input.")
+@click.option('--report-mode/--no-report-mode', default=False, help="Flag for hiding input.")
 @click.option(
     '--version',
     is_flag=True,
@@ -177,6 +141,8 @@ def papermill(
     log_level,
     start_timeout,
     report_mode,
+    stdout_file,
+    stderr_file,
 ):
     """This utility executes a single notebook in a subprocess.
 
@@ -226,29 +192,23 @@ def papermill(
         parameters_final.update(read_yaml_file(files))
     for params in parameters_yaml or []:
         parameters_final.update(yaml.load(params, Loader=NoDatesSafeLoader))
-    for name_values in parameters or []:
-        name, values = name_values[0], name_values[1:]
-        if not values:
-            raise ValueError("There must be at least one value for key '{}'".format(name))
-        values = [_resolve_type(v) for v in values]
-        parameters_final[name] = values[0] if len(values) == 1 else values
-    for name_values in parameters_raw or []:
-        name, values = name_values[0], name_values[1:]
-        if not values:
-            raise ValueError("There must be at least one value for key '{}'".format(name))
-        values = list(values)
-        parameters_final[name] = values[0] if len(values) == 1 else values
+    for name, value in parameters or []:
+        parameters_final[name] = _resolve_type(value)
+    for name, value in parameters_raw or []:
+        parameters_final[name] = value
 
     execute_notebook(
-        notebook_path,
-        output_path,
-        parameters_final,
+        input_path=notebook_path,
+        output_path=output_path,
+        parameters=parameters_final,
         engine_name=engine,
         request_save_on_cell_execute=request_save_on_cell_execute,
         prepare_only=prepare_only,
         kernel_name=kernel,
         progress_bar=progress_bar,
         log_output=log_output,
+        stdout_file=stdout_file,
+        stderr_file=stderr_file,
         start_timeout=start_timeout,
         report_mode=report_mode,
         cwd=cwd,
